@@ -1,10 +1,9 @@
+#pragma once
+
 #if !defined(__CLUTTER_H_INSIDE__) && !defined(CLUTTER_COMPILATION)
 #error "Only <clutter/clutter.h> can be included directly."
 #endif
 
-#ifndef __CLUTTER_CONFIG_H__
-#define __CLUTTER_CONFIG_H__
-
 #include <glib.h>
 
 G_BEGIN_DECLS
@@ -19,5 +18,3 @@ G_BEGIN_DECLS
 #define CLUTTER_INPUT_NULL "null"
 
 G_END_DECLS
-
-#endif /* __CLUTTER_CONFIG_H__ */
